Documentation
¶
Overview ¶
Package service provides primitives to interact the openapi HTTP API.
Code generated by go-sdk-codegen DO NOT EDIT.
Package service provides primitives to interact the openapi HTTP API.
Code generated by go-sdk-codegen DO NOT EDIT.
Index ¶
- func NewAddAppointmentForServiceJobByServiceJobIdRequest(endpoint string, serviceJobId string, ...) (*http.Request, error)
- func NewAddAppointmentForServiceJobByServiceJobIdRequestWithBody(endpoint string, serviceJobId string, contentType string, body io.Reader) (*http.Request, error)
- func NewCancelServiceJobByServiceJobIdRequest(endpoint string, serviceJobId string, ...) (*http.Request, error)
- func NewCompleteServiceJobByServiceJobIdRequest(endpoint string, serviceJobId string) (*http.Request, error)
- func NewGetServiceJobByServiceJobIdRequest(endpoint string, serviceJobId string) (*http.Request, error)
- func NewGetServiceJobsRequest(endpoint string, params *GetServiceJobsParams) (*http.Request, error)
- func NewRescheduleAppointmentForServiceJobByServiceJobIdRequest(endpoint string, serviceJobId string, appointmentId string, ...) (*http.Request, error)
- func NewRescheduleAppointmentForServiceJobByServiceJobIdRequestWithBody(endpoint string, serviceJobId string, appointmentId string, contentType string, ...) (*http.Request, error)
- type AddAppointmentForServiceJobByServiceJobIdJSONBody
- type AddAppointmentForServiceJobByServiceJobIdJSONRequestBody
- type AddAppointmentForServiceJobByServiceJobIdResp
- type AddAppointmentRequest
- type Address
- type Appointment
- type AppointmentId
- type AppointmentTime
- type AppointmentTimeInput
- type AssociatedItem
- type Buyer
- type CancelServiceJobByServiceJobIdParams
- type CancelServiceJobByServiceJobIdResp
- type CancelServiceJobByServiceJobIdResponse
- type Client
- func (c *Client) AddAppointmentForServiceJobByServiceJobId(ctx context.Context, serviceJobId string, ...) (*http.Response, error)
- func (c *Client) AddAppointmentForServiceJobByServiceJobIdWithBody(ctx context.Context, serviceJobId string, contentType string, body io.Reader) (*http.Response, error)
- func (c *Client) CancelServiceJobByServiceJobId(ctx context.Context, serviceJobId string, ...) (*http.Response, error)
- func (c *Client) CompleteServiceJobByServiceJobId(ctx context.Context, serviceJobId string) (*http.Response, error)
- func (c *Client) GetServiceJobByServiceJobId(ctx context.Context, serviceJobId string) (*http.Response, error)
- func (c *Client) GetServiceJobs(ctx context.Context, params *GetServiceJobsParams) (*http.Response, error)
- func (c *Client) RescheduleAppointmentForServiceJobByServiceJobId(ctx context.Context, serviceJobId string, appointmentId string, ...) (*http.Response, error)
- func (c *Client) RescheduleAppointmentForServiceJobByServiceJobIdWithBody(ctx context.Context, serviceJobId string, appointmentId string, ...) (*http.Response, error)
- type ClientInterface
- type ClientOption
- type ClientWithResponses
- func (c *ClientWithResponses) AddAppointmentForServiceJobByServiceJobIdWithBodyWithResponse(ctx context.Context, serviceJobId string, contentType string, body io.Reader) (*AddAppointmentForServiceJobByServiceJobIdResp, error)
- func (c *ClientWithResponses) AddAppointmentForServiceJobByServiceJobIdWithResponse(ctx context.Context, serviceJobId string, ...) (*AddAppointmentForServiceJobByServiceJobIdResp, error)
- func (c *ClientWithResponses) CancelServiceJobByServiceJobIdWithResponse(ctx context.Context, serviceJobId string, ...) (*CancelServiceJobByServiceJobIdResp, error)
- func (c *ClientWithResponses) CompleteServiceJobByServiceJobIdWithResponse(ctx context.Context, serviceJobId string) (*CompleteServiceJobByServiceJobIdResp, error)
- func (c *ClientWithResponses) GetServiceJobByServiceJobIdWithResponse(ctx context.Context, serviceJobId string) (*GetServiceJobByServiceJobIdResp, error)
- func (c *ClientWithResponses) GetServiceJobsWithResponse(ctx context.Context, params *GetServiceJobsParams) (*GetServiceJobsResp, error)
- func (c *ClientWithResponses) RescheduleAppointmentForServiceJobByServiceJobIdWithBodyWithResponse(ctx context.Context, serviceJobId string, appointmentId string, ...) (*RescheduleAppointmentForServiceJobByServiceJobIdResp, error)
- func (c *ClientWithResponses) RescheduleAppointmentForServiceJobByServiceJobIdWithResponse(ctx context.Context, serviceJobId string, appointmentId string, ...) (*RescheduleAppointmentForServiceJobByServiceJobIdResp, error)
- type ClientWithResponsesInterface
- type CompleteServiceJobByServiceJobIdResp
- type CompleteServiceJobByServiceJobIdResponse
- type Error
- type ErrorList
- type GetServiceJobByServiceJobIdResp
- type GetServiceJobByServiceJobIdResponse
- type GetServiceJobsParams
- type GetServiceJobsResp
- type GetServiceJobsResponse
- type HttpRequestDoer
- type ItemDelivery
- type ItemDeliveryPromise
- type JobListing
- type OrderId
- type Poa
- type RequestBeforeFn
- type RescheduleAppointmentForServiceJobByServiceJobIdJSONBody
- type RescheduleAppointmentForServiceJobByServiceJobIdJSONRequestBody
- type RescheduleAppointmentForServiceJobByServiceJobIdResp
- type RescheduleAppointmentRequest
- type RescheduleReasonCode
- type ResponseAfterFn
- type ScopeOfWork
- type Seller
- type ServiceJob
- type ServiceJobId
- type ServiceJobProvider
- type ServiceLocation
- type SetAppointmentResponse
- type Technician
- type Warning
- type WarningList
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewAddAppointmentForServiceJobByServiceJobIdRequest ¶
func NewAddAppointmentForServiceJobByServiceJobIdRequest(endpoint string, serviceJobId string, body AddAppointmentForServiceJobByServiceJobIdJSONRequestBody) (*http.Request, error)
NewAddAppointmentForServiceJobByServiceJobIdRequest calls the generic AddAppointmentForServiceJobByServiceJobId builder with application/json body
func NewAddAppointmentForServiceJobByServiceJobIdRequestWithBody ¶
func NewAddAppointmentForServiceJobByServiceJobIdRequestWithBody(endpoint string, serviceJobId string, contentType string, body io.Reader) (*http.Request, error)
NewAddAppointmentForServiceJobByServiceJobIdRequestWithBody generates requests for AddAppointmentForServiceJobByServiceJobId with any type of body
func NewCancelServiceJobByServiceJobIdRequest ¶
func NewCancelServiceJobByServiceJobIdRequest(endpoint string, serviceJobId string, params *CancelServiceJobByServiceJobIdParams) (*http.Request, error)
NewCancelServiceJobByServiceJobIdRequest generates requests for CancelServiceJobByServiceJobId
func NewCompleteServiceJobByServiceJobIdRequest ¶
func NewCompleteServiceJobByServiceJobIdRequest(endpoint string, serviceJobId string) (*http.Request, error)
NewCompleteServiceJobByServiceJobIdRequest generates requests for CompleteServiceJobByServiceJobId
func NewGetServiceJobByServiceJobIdRequest ¶
func NewGetServiceJobByServiceJobIdRequest(endpoint string, serviceJobId string) (*http.Request, error)
NewGetServiceJobByServiceJobIdRequest generates requests for GetServiceJobByServiceJobId
func NewGetServiceJobsRequest ¶
func NewGetServiceJobsRequest(endpoint string, params *GetServiceJobsParams) (*http.Request, error)
NewGetServiceJobsRequest generates requests for GetServiceJobs
func NewRescheduleAppointmentForServiceJobByServiceJobIdRequest ¶
func NewRescheduleAppointmentForServiceJobByServiceJobIdRequest(endpoint string, serviceJobId string, appointmentId string, body RescheduleAppointmentForServiceJobByServiceJobIdJSONRequestBody) (*http.Request, error)
NewRescheduleAppointmentForServiceJobByServiceJobIdRequest calls the generic RescheduleAppointmentForServiceJobByServiceJobId builder with application/json body
func NewRescheduleAppointmentForServiceJobByServiceJobIdRequestWithBody ¶
func NewRescheduleAppointmentForServiceJobByServiceJobIdRequestWithBody(endpoint string, serviceJobId string, appointmentId string, contentType string, body io.Reader) (*http.Request, error)
NewRescheduleAppointmentForServiceJobByServiceJobIdRequestWithBody generates requests for RescheduleAppointmentForServiceJobByServiceJobId with any type of body
Types ¶
type AddAppointmentForServiceJobByServiceJobIdJSONBody ¶
type AddAppointmentForServiceJobByServiceJobIdJSONBody AddAppointmentRequest
AddAppointmentForServiceJobByServiceJobIdJSONBody defines parameters for AddAppointmentForServiceJobByServiceJobId.
type AddAppointmentForServiceJobByServiceJobIdJSONRequestBody ¶
type AddAppointmentForServiceJobByServiceJobIdJSONRequestBody AddAppointmentForServiceJobByServiceJobIdJSONBody
AddAppointmentForServiceJobByServiceJobIdRequestBody defines body for AddAppointmentForServiceJobByServiceJobId for application/json ContentType.
type AddAppointmentForServiceJobByServiceJobIdResp ¶
type AddAppointmentForServiceJobByServiceJobIdResp struct {
Body []byte
HTTPResponse *http.Response
Model *SetAppointmentResponse
}
func ParseAddAppointmentForServiceJobByServiceJobIdResp ¶
func ParseAddAppointmentForServiceJobByServiceJobIdResp(rsp *http.Response) (*AddAppointmentForServiceJobByServiceJobIdResp, error)
ParseAddAppointmentForServiceJobByServiceJobIdResp parses an HTTP response from a AddAppointmentForServiceJobByServiceJobIdWithResponse call
func (AddAppointmentForServiceJobByServiceJobIdResp) Status ¶
func (r AddAppointmentForServiceJobByServiceJobIdResp) Status() string
Status returns HTTPResponse.Status
func (AddAppointmentForServiceJobByServiceJobIdResp) StatusCode ¶
func (r AddAppointmentForServiceJobByServiceJobIdResp) StatusCode() int
StatusCode returns HTTPResponse.StatusCode
type AddAppointmentRequest ¶
type AddAppointmentRequest struct {
// The input appointment time details.
AppointmentTime AppointmentTimeInput `json:"appointmentTime"`
}
AddAppointmentRequest defines model for AddAppointmentRequest.
type Address ¶
type Address struct {
// The first line of the address.
AddressLine1 string `json:"addressLine1"`
// Additional address information, if required.
AddressLine2 *string `json:"addressLine2,omitempty"`
// Additional address information, if required.
AddressLine3 *string `json:"addressLine3,omitempty"`
// The city.
City *string `json:"city,omitempty"`
// The two digit country code, in ISO 3166-1 alpha-2 format.
CountryCode *string `json:"countryCode,omitempty"`
// The county.
County *string `json:"county,omitempty"`
// The district.
District *string `json:"district,omitempty"`
// The name of the person, business, or institution.
Name string `json:"name"`
// The phone number.
Phone *string `json:"phone,omitempty"`
// The postal code. This can contain letters, digits, spaces, and/or punctuation.
PostalCode *string `json:"postalCode,omitempty"`
// The state or region.
StateOrRegion *string `json:"stateOrRegion,omitempty"`
}
Address defines model for Address.
type Appointment ¶
type Appointment struct {
// The appointment identifier.
AppointmentId *AppointmentId `json:"appointmentId,omitempty"`
// The status of the appointment.
AppointmentStatus *string `json:"appointmentStatus,omitempty"`
// The time of the appointment window.
AppointmentTime *AppointmentTime `json:"appointmentTime,omitempty"`
// A list of technicians assigned to the service job.
AssignedTechnicians *[]Technician `json:"assignedTechnicians,omitempty"`
// Proof of Appointment (POA) details.
Poa *Poa `json:"poa,omitempty"`
// The appointment identifier.
RescheduledAppointmentId *AppointmentId `json:"rescheduledAppointmentId,omitempty"`
}
Appointment defines model for Appointment.
type AppointmentTime ¶
type AppointmentTime struct {
// The duration of the appointment window, in minutes.
DurationInMinutes int `json:"durationInMinutes"`
// The date and time of the start of the appointment window, in ISO 8601 format.
StartTime time.Time `json:"startTime"`
}
AppointmentTime defines model for AppointmentTime.
type AppointmentTimeInput ¶
type AppointmentTimeInput struct {
// The duration of an appointment in minutes.
DurationInMinutes *int `json:"durationInMinutes,omitempty"`
// The date, time in UTC for the start time of an appointment in ISO 8601 format.
StartTime time.Time `json:"startTime"`
}
AppointmentTimeInput defines model for AppointmentTimeInput.
type AssociatedItem ¶
type AssociatedItem struct {
// The Amazon Standard Identification Number (ASIN) of the item.
Asin *string `json:"asin,omitempty"`
// The brand name of the item.
BrandName *string `json:"brandName,omitempty"`
// Delivery information for the item.
ItemDelivery *ItemDelivery `json:"itemDelivery,omitempty"`
// The status of the item.
ItemStatus *string `json:"itemStatus,omitempty"`
// The Amazon-defined identifier for an order placed by the buyer, in 3-7-7 format.
OrderId *OrderId `json:"orderId,omitempty"`
// The total number of items included in the order.
Quantity *int `json:"quantity,omitempty"`
// The title of the item.
Title *string `json:"title,omitempty"`
}
AssociatedItem defines model for AssociatedItem.
type Buyer ¶
type Buyer struct {
// The identifier of the buyer.
BuyerId *string `json:"buyerId,omitempty"`
// When true, the service is for an Amazon Prime buyer.
IsPrimeMember *bool `json:"isPrimeMember,omitempty"`
// The name of the buyer.
Name *string `json:"name,omitempty"`
// The phone number of the buyer.
Phone *string `json:"phone,omitempty"`
}
Buyer defines model for Buyer.
type CancelServiceJobByServiceJobIdParams ¶
type CancelServiceJobByServiceJobIdParams struct {
// A cancel reason code that specifies the reason for cancelling a service job.
CancellationReasonCode string `json:"cancellationReasonCode"`
}
CancelServiceJobByServiceJobIdParams defines parameters for CancelServiceJobByServiceJobId.
type CancelServiceJobByServiceJobIdResp ¶
type CancelServiceJobByServiceJobIdResp struct {
Body []byte
HTTPResponse *http.Response
Model *CancelServiceJobByServiceJobIdResponse
}
func ParseCancelServiceJobByServiceJobIdResp ¶
func ParseCancelServiceJobByServiceJobIdResp(rsp *http.Response) (*CancelServiceJobByServiceJobIdResp, error)
ParseCancelServiceJobByServiceJobIdResp parses an HTTP response from a CancelServiceJobByServiceJobIdWithResponse call
func (CancelServiceJobByServiceJobIdResp) Status ¶
func (r CancelServiceJobByServiceJobIdResp) Status() string
Status returns HTTPResponse.Status
func (CancelServiceJobByServiceJobIdResp) StatusCode ¶
func (r CancelServiceJobByServiceJobIdResp) StatusCode() int
StatusCode returns HTTPResponse.StatusCode
type CancelServiceJobByServiceJobIdResponse ¶
type CancelServiceJobByServiceJobIdResponse struct {
// A list of error responses returned when a request is unsuccessful.
Errors *ErrorList `json:"errors,omitempty"`
}
CancelServiceJobByServiceJobIdResponse defines model for CancelServiceJobByServiceJobIdResponse.
type Client ¶
type Client struct {
// The endpoint of the server conforming to this interface, with scheme,
// https://api.deepmap.com for example. This can contain a path relative
// to the server, such as https://api.deepmap.com/dev-test, and all the
// paths in the swagger spec will be appended to the server.
Endpoint string
// Doer for performing requests, typically a *http.Client with any
// customized settings, such as certificate chains.
Client HttpRequestDoer
// A callback for modifying requests which are generated before sending over
// the network.
RequestBefore RequestBeforeFn
// A callback for modifying response which are generated before sending over
// the network.
ResponseAfter ResponseAfterFn
// The user agent header identifies your application, its version number, and the platform and programming language you are using.
// You must include a user agent header in each request submitted to the sales partner API.
UserAgent string
}
Client which conforms to the OpenAPI3 specification for this service.
func NewClient ¶
func NewClient(endpoint string, opts ...ClientOption) (*Client, error)
Creates a new Client, with reasonable defaults
func (*Client) AddAppointmentForServiceJobByServiceJobId ¶
func (*Client) AddAppointmentForServiceJobByServiceJobIdWithBody ¶
func (*Client) CancelServiceJobByServiceJobId ¶
func (*Client) CompleteServiceJobByServiceJobId ¶
func (*Client) GetServiceJobByServiceJobId ¶
func (*Client) GetServiceJobs ¶
func (*Client) RescheduleAppointmentForServiceJobByServiceJobId ¶
type ClientInterface ¶
type ClientInterface interface {
// GetServiceJobs request
GetServiceJobs(ctx context.Context, params *GetServiceJobsParams) (*http.Response, error)
// GetServiceJobByServiceJobId request
GetServiceJobByServiceJobId(ctx context.Context, serviceJobId string) (*http.Response, error)
// AddAppointmentForServiceJobByServiceJobId request with any body
AddAppointmentForServiceJobByServiceJobIdWithBody(ctx context.Context, serviceJobId string, contentType string, body io.Reader) (*http.Response, error)
AddAppointmentForServiceJobByServiceJobId(ctx context.Context, serviceJobId string, body AddAppointmentForServiceJobByServiceJobIdJSONRequestBody) (*http.Response, error)
// RescheduleAppointmentForServiceJobByServiceJobId request with any body
RescheduleAppointmentForServiceJobByServiceJobIdWithBody(ctx context.Context, serviceJobId string, appointmentId string, contentType string, body io.Reader) (*http.Response, error)
RescheduleAppointmentForServiceJobByServiceJobId(ctx context.Context, serviceJobId string, appointmentId string, body RescheduleAppointmentForServiceJobByServiceJobIdJSONRequestBody) (*http.Response, error)
// CancelServiceJobByServiceJobId request
CancelServiceJobByServiceJobId(ctx context.Context, serviceJobId string, params *CancelServiceJobByServiceJobIdParams) (*http.Response, error)
// CompleteServiceJobByServiceJobId request
CompleteServiceJobByServiceJobId(ctx context.Context, serviceJobId string) (*http.Response, error)
}
The interface specification for the client above.
type ClientOption ¶
ClientOption allows setting custom parameters during construction
func WithHTTPClient ¶
func WithHTTPClient(doer HttpRequestDoer) ClientOption
WithHTTPClient allows overriding the default Doer, which is automatically created using http.Client. This is useful for tests.
func WithRequestBefore ¶
func WithRequestBefore(fn RequestBeforeFn) ClientOption
WithRequestBefore allows setting up a callback function, which will be called right before sending the request. This can be used to mutate the request.
func WithResponseAfter ¶
func WithResponseAfter(fn ResponseAfterFn) ClientOption
WithResponseAfter allows setting up a callback function, which will be called right after get response the request. This can be used to log.
func WithUserAgent ¶
func WithUserAgent(userAgent string) ClientOption
WithUserAgent set up useragent add user agent to every request automatically
type ClientWithResponses ¶
type ClientWithResponses struct {
ClientInterface
}
ClientWithResponses builds on ClientInterface to offer response payloads
func NewClientWithResponses ¶
func NewClientWithResponses(endpoint string, opts ...ClientOption) (*ClientWithResponses, error)
NewClientWithResponses creates a new ClientWithResponses, which wraps Client with return type handling
func (*ClientWithResponses) AddAppointmentForServiceJobByServiceJobIdWithBodyWithResponse ¶
func (c *ClientWithResponses) AddAppointmentForServiceJobByServiceJobIdWithBodyWithResponse(ctx context.Context, serviceJobId string, contentType string, body io.Reader) (*AddAppointmentForServiceJobByServiceJobIdResp, error)
AddAppointmentForServiceJobByServiceJobIdWithBodyWithResponse request with arbitrary body returning *AddAppointmentForServiceJobByServiceJobIdResponse
func (*ClientWithResponses) AddAppointmentForServiceJobByServiceJobIdWithResponse ¶
func (c *ClientWithResponses) AddAppointmentForServiceJobByServiceJobIdWithResponse(ctx context.Context, serviceJobId string, body AddAppointmentForServiceJobByServiceJobIdJSONRequestBody) (*AddAppointmentForServiceJobByServiceJobIdResp, error)
func (*ClientWithResponses) CancelServiceJobByServiceJobIdWithResponse ¶
func (c *ClientWithResponses) CancelServiceJobByServiceJobIdWithResponse(ctx context.Context, serviceJobId string, params *CancelServiceJobByServiceJobIdParams) (*CancelServiceJobByServiceJobIdResp, error)
CancelServiceJobByServiceJobIdWithResponse request returning *CancelServiceJobByServiceJobIdResponse
func (*ClientWithResponses) CompleteServiceJobByServiceJobIdWithResponse ¶
func (c *ClientWithResponses) CompleteServiceJobByServiceJobIdWithResponse(ctx context.Context, serviceJobId string) (*CompleteServiceJobByServiceJobIdResp, error)
CompleteServiceJobByServiceJobIdWithResponse request returning *CompleteServiceJobByServiceJobIdResponse
func (*ClientWithResponses) GetServiceJobByServiceJobIdWithResponse ¶
func (c *ClientWithResponses) GetServiceJobByServiceJobIdWithResponse(ctx context.Context, serviceJobId string) (*GetServiceJobByServiceJobIdResp, error)
GetServiceJobByServiceJobIdWithResponse request returning *GetServiceJobByServiceJobIdResponse
func (*ClientWithResponses) GetServiceJobsWithResponse ¶
func (c *ClientWithResponses) GetServiceJobsWithResponse(ctx context.Context, params *GetServiceJobsParams) (*GetServiceJobsResp, error)
GetServiceJobsWithResponse request returning *GetServiceJobsResponse
func (*ClientWithResponses) RescheduleAppointmentForServiceJobByServiceJobIdWithBodyWithResponse ¶
func (c *ClientWithResponses) RescheduleAppointmentForServiceJobByServiceJobIdWithBodyWithResponse(ctx context.Context, serviceJobId string, appointmentId string, contentType string, body io.Reader) (*RescheduleAppointmentForServiceJobByServiceJobIdResp, error)
RescheduleAppointmentForServiceJobByServiceJobIdWithBodyWithResponse request with arbitrary body returning *RescheduleAppointmentForServiceJobByServiceJobIdResponse
func (*ClientWithResponses) RescheduleAppointmentForServiceJobByServiceJobIdWithResponse ¶
func (c *ClientWithResponses) RescheduleAppointmentForServiceJobByServiceJobIdWithResponse(ctx context.Context, serviceJobId string, appointmentId string, body RescheduleAppointmentForServiceJobByServiceJobIdJSONRequestBody) (*RescheduleAppointmentForServiceJobByServiceJobIdResp, error)
type ClientWithResponsesInterface ¶
type ClientWithResponsesInterface interface {
// GetServiceJobs request
GetServiceJobsWithResponse(ctx context.Context, params *GetServiceJobsParams) (*GetServiceJobsResp, error)
// GetServiceJobByServiceJobId request
GetServiceJobByServiceJobIdWithResponse(ctx context.Context, serviceJobId string) (*GetServiceJobByServiceJobIdResp, error)
// AddAppointmentForServiceJobByServiceJobId request with any body
AddAppointmentForServiceJobByServiceJobIdWithBodyWithResponse(ctx context.Context, serviceJobId string, contentType string, body io.Reader) (*AddAppointmentForServiceJobByServiceJobIdResp, error)
AddAppointmentForServiceJobByServiceJobIdWithResponse(ctx context.Context, serviceJobId string, body AddAppointmentForServiceJobByServiceJobIdJSONRequestBody) (*AddAppointmentForServiceJobByServiceJobIdResp, error)
// RescheduleAppointmentForServiceJobByServiceJobId request with any body
RescheduleAppointmentForServiceJobByServiceJobIdWithBodyWithResponse(ctx context.Context, serviceJobId string, appointmentId string, contentType string, body io.Reader) (*RescheduleAppointmentForServiceJobByServiceJobIdResp, error)
RescheduleAppointmentForServiceJobByServiceJobIdWithResponse(ctx context.Context, serviceJobId string, appointmentId string, body RescheduleAppointmentForServiceJobByServiceJobIdJSONRequestBody) (*RescheduleAppointmentForServiceJobByServiceJobIdResp, error)
// CancelServiceJobByServiceJobId request
CancelServiceJobByServiceJobIdWithResponse(ctx context.Context, serviceJobId string, params *CancelServiceJobByServiceJobIdParams) (*CancelServiceJobByServiceJobIdResp, error)
// CompleteServiceJobByServiceJobId request
CompleteServiceJobByServiceJobIdWithResponse(ctx context.Context, serviceJobId string) (*CompleteServiceJobByServiceJobIdResp, error)
}
ClientWithResponsesInterface is the interface specification for the client with responses above.
type CompleteServiceJobByServiceJobIdResp ¶
type CompleteServiceJobByServiceJobIdResp struct {
Body []byte
HTTPResponse *http.Response
Model *CompleteServiceJobByServiceJobIdResponse
}
func ParseCompleteServiceJobByServiceJobIdResp ¶
func ParseCompleteServiceJobByServiceJobIdResp(rsp *http.Response) (*CompleteServiceJobByServiceJobIdResp, error)
ParseCompleteServiceJobByServiceJobIdResp parses an HTTP response from a CompleteServiceJobByServiceJobIdWithResponse call
func (CompleteServiceJobByServiceJobIdResp) Status ¶
func (r CompleteServiceJobByServiceJobIdResp) Status() string
Status returns HTTPResponse.Status
func (CompleteServiceJobByServiceJobIdResp) StatusCode ¶
func (r CompleteServiceJobByServiceJobIdResp) StatusCode() int
StatusCode returns HTTPResponse.StatusCode
type CompleteServiceJobByServiceJobIdResponse ¶
type CompleteServiceJobByServiceJobIdResponse struct {
// A list of error responses returned when a request is unsuccessful.
Errors *ErrorList `json:"errors,omitempty"`
}
CompleteServiceJobByServiceJobIdResponse defines model for CompleteServiceJobByServiceJobIdResponse.
type Error ¶
type Error struct {
// An error code that identifies the type of error that occurred.
Code string `json:"code"`
// Additional details that can help the caller understand or fix the issue.
Details *string `json:"details,omitempty"`
// The type of error.
ErrorLevel *string `json:"errorLevel,omitempty"`
// A message that describes the error condition in a human-readable form.
Message string `json:"message"`
}
Error defines model for Error.
type GetServiceJobByServiceJobIdResp ¶
type GetServiceJobByServiceJobIdResp struct {
Body []byte
HTTPResponse *http.Response
Model *GetServiceJobByServiceJobIdResponse
}
func ParseGetServiceJobByServiceJobIdResp ¶
func ParseGetServiceJobByServiceJobIdResp(rsp *http.Response) (*GetServiceJobByServiceJobIdResp, error)
ParseGetServiceJobByServiceJobIdResp parses an HTTP response from a GetServiceJobByServiceJobIdWithResponse call
func (GetServiceJobByServiceJobIdResp) Status ¶
func (r GetServiceJobByServiceJobIdResp) Status() string
Status returns HTTPResponse.Status
func (GetServiceJobByServiceJobIdResp) StatusCode ¶
func (r GetServiceJobByServiceJobIdResp) StatusCode() int
StatusCode returns HTTPResponse.StatusCode
type GetServiceJobByServiceJobIdResponse ¶
type GetServiceJobByServiceJobIdResponse struct {
// A list of error responses returned when a request is unsuccessful.
Errors *ErrorList `json:"errors,omitempty"`
// The job details of a service.
Payload *ServiceJob `json:"payload,omitempty"`
}
GetServiceJobByServiceJobIdResponse defines model for GetServiceJobByServiceJobIdResponse.
type GetServiceJobsParams ¶
type GetServiceJobsParams struct {
// List of service order ids for the query you want to perform.Max values supported 20.
ServiceOrderIds *[]string `json:"serviceOrderIds,omitempty"`
// A list of one or more job status by which to filter the list of jobs.
ServiceJobStatus *[]string `json:"serviceJobStatus,omitempty"`
// String returned in the response of your previous request.
PageToken *string `json:"pageToken,omitempty"`
// A non-negative integer that indicates the maximum number of jobs to return in the list, Value must be 1 - 20. Default 20.
PageSize *int `json:"pageSize,omitempty"`
// Sort fields on which you want to sort the output.
SortField *string `json:"sortField,omitempty"`
// Sort order for the query you want to perform.
SortOrder *string `json:"sortOrder,omitempty"`
// A date used for selecting jobs created after (or at) a specified time must be in ISO 8601 format. Required if LastUpdatedAfter is not specified.Specifying both CreatedAfter and LastUpdatedAfter returns an error.
CreatedAfter *string `json:"createdAfter,omitempty"`
// A date used for selecting jobs created before (or at) a specified time must be in ISO 8601 format.
CreatedBefore *string `json:"createdBefore,omitempty"`
// A date used for selecting jobs updated after (or at) a specified time must be in ISO 8601 format. Required if createdAfter is not specified.Specifying both CreatedAfter and LastUpdatedAfter returns an error.
LastUpdatedAfter *string `json:"lastUpdatedAfter,omitempty"`
// A date used for selecting jobs updated before (or at) a specified time must be in ISO 8601 format.
LastUpdatedBefore *string `json:"lastUpdatedBefore,omitempty"`
// A date used for filtering jobs schedule after (or at) a specified time must be in ISO 8601 format. schedule end date should not be earlier than schedule start date.
ScheduleStartDate *string `json:"scheduleStartDate,omitempty"`
// A date used for filtering jobs schedule before (or at) a specified time must be in ISO 8601 format. schedule end date should not be earlier than schedule start date.
ScheduleEndDate *string `json:"scheduleEndDate,omitempty"`
// Used to select jobs that were placed in the specified marketplaces.
MarketplaceIds []string `json:"marketplaceIds"`
}
GetServiceJobsParams defines parameters for GetServiceJobs.
type GetServiceJobsResp ¶
type GetServiceJobsResp struct {
Body []byte
HTTPResponse *http.Response
Model *GetServiceJobsResponse
}
func ParseGetServiceJobsResp ¶
func ParseGetServiceJobsResp(rsp *http.Response) (*GetServiceJobsResp, error)
ParseGetServiceJobsResp parses an HTTP response from a GetServiceJobsWithResponse call
func (GetServiceJobsResp) Status ¶
func (r GetServiceJobsResp) Status() string
Status returns HTTPResponse.Status
func (GetServiceJobsResp) StatusCode ¶
func (r GetServiceJobsResp) StatusCode() int
StatusCode returns HTTPResponse.StatusCode
type GetServiceJobsResponse ¶
type GetServiceJobsResponse struct {
// A list of error responses returned when a request is unsuccessful.
Errors *ErrorList `json:"errors,omitempty"`
// The payload for the GetJobs operation.
Payload *JobListing `json:"payload,omitempty"`
}
GetServiceJobsResponse defines model for GetServiceJobsResponse.
type HttpRequestDoer ¶
Doer performs HTTP requests.
The standard http.Client implements this interface.
type ItemDelivery ¶
type ItemDelivery struct {
// The date and time of the latest Estimated Delivery Date (EDD) of all the items with an EDD. In ISO 8601 format.
EstimatedDeliveryDate *time.Time `json:"estimatedDeliveryDate,omitempty"`
// Promised delivery information for the item.
ItemDeliveryPromise *ItemDeliveryPromise `json:"itemDeliveryPromise,omitempty"`
}
ItemDelivery defines model for ItemDelivery.
type ItemDeliveryPromise ¶
type ItemDeliveryPromise struct {
// The date and time of the end of the promised delivery window, in ISO 8601 format.
EndTime *time.Time `json:"endTime,omitempty"`
// The date and time of the start of the promised delivery window, in ISO 8601 format.
StartTime *time.Time `json:"startTime,omitempty"`
}
ItemDeliveryPromise defines model for ItemDeliveryPromise.
type JobListing ¶
type JobListing struct {
// List of job details for the given input.
Jobs *[]ServiceJob `json:"jobs,omitempty"`
// A generated string used to pass information to your next request.If nextPageToken is returned, pass the value of nextPageToken to the pageToken to get next results.
NextPageToken *string `json:"nextPageToken,omitempty"`
// A generated string used to pass information to your next request.If previousPageToken is returned, pass the value of previousPageToken to the pageToken to get previous page results.
PreviousPageToken *string `json:"previousPageToken,omitempty"`
// Total result size of the query result.
TotalResultSize *int `json:"totalResultSize,omitempty"`
}
JobListing defines model for JobListing.
type Poa ¶
type Poa struct {
// The time of the appointment window.
AppointmentTime *AppointmentTime `json:"appointmentTime,omitempty"`
// The type of POA uploaded.
PoaType *string `json:"poaType,omitempty"`
// A list of technicians.
Technicians *[]Technician `json:"technicians,omitempty"`
// The date and time when the POA was uploaded, in ISO 8601 format.
UploadTime *time.Time `json:"uploadTime,omitempty"`
// The identifier of the technician who uploaded the POA.
UploadingTechnician *string `json:"uploadingTechnician,omitempty"`
}
Poa defines model for Poa.
type RequestBeforeFn ¶
RequestBeforeFn is the function signature for the RequestBefore callback function
type RescheduleAppointmentForServiceJobByServiceJobIdJSONBody ¶
type RescheduleAppointmentForServiceJobByServiceJobIdJSONBody RescheduleAppointmentRequest
RescheduleAppointmentForServiceJobByServiceJobIdJSONBody defines parameters for RescheduleAppointmentForServiceJobByServiceJobId.
type RescheduleAppointmentForServiceJobByServiceJobIdJSONRequestBody ¶
type RescheduleAppointmentForServiceJobByServiceJobIdJSONRequestBody RescheduleAppointmentForServiceJobByServiceJobIdJSONBody
RescheduleAppointmentForServiceJobByServiceJobIdRequestBody defines body for RescheduleAppointmentForServiceJobByServiceJobId for application/json ContentType.
type RescheduleAppointmentForServiceJobByServiceJobIdResp ¶
type RescheduleAppointmentForServiceJobByServiceJobIdResp struct {
Body []byte
HTTPResponse *http.Response
Model *SetAppointmentResponse
}
func ParseRescheduleAppointmentForServiceJobByServiceJobIdResp ¶
func ParseRescheduleAppointmentForServiceJobByServiceJobIdResp(rsp *http.Response) (*RescheduleAppointmentForServiceJobByServiceJobIdResp, error)
ParseRescheduleAppointmentForServiceJobByServiceJobIdResp parses an HTTP response from a RescheduleAppointmentForServiceJobByServiceJobIdWithResponse call
func (RescheduleAppointmentForServiceJobByServiceJobIdResp) Status ¶
func (r RescheduleAppointmentForServiceJobByServiceJobIdResp) Status() string
Status returns HTTPResponse.Status
func (RescheduleAppointmentForServiceJobByServiceJobIdResp) StatusCode ¶
func (r RescheduleAppointmentForServiceJobByServiceJobIdResp) StatusCode() int
StatusCode returns HTTPResponse.StatusCode
type RescheduleAppointmentRequest ¶
type RescheduleAppointmentRequest struct {
// The input appointment time details.
AppointmentTime AppointmentTimeInput `json:"appointmentTime"`
// Appointment reschedule reason code.
RescheduleReasonCode RescheduleReasonCode `json:"rescheduleReasonCode"`
}
RescheduleAppointmentRequest defines model for RescheduleAppointmentRequest.
type RescheduleReasonCode ¶
type RescheduleReasonCode string
RescheduleReasonCode defines model for RescheduleReasonCode.
type ResponseAfterFn ¶
ResponseAfterFn is the function signature for the ResponseAfter callback function
type ScopeOfWork ¶
type ScopeOfWork struct {
// The Amazon Standard Identification Number (ASIN) of the service job.
Asin *string `json:"asin,omitempty"`
// The number of service jobs.
Quantity *int `json:"quantity,omitempty"`
// A list of skills required to perform the job.
RequiredSkills *[]string `json:"requiredSkills,omitempty"`
// The title of the service job.
Title *string `json:"title,omitempty"`
}
ScopeOfWork defines model for ScopeOfWork.
type Seller ¶
type Seller struct {
// The identifier of the seller of the service job.
SellerId *string `json:"sellerId,omitempty"`
}
Seller defines model for Seller.
type ServiceJob ¶
type ServiceJob struct {
// A list of appointments.
Appointments *[]Appointment `json:"appointments,omitempty"`
// A list of items associated with the service job.
AssociatedItems *[]AssociatedItem `json:"associatedItems,omitempty"`
// Information about the buyer.
Buyer *Buyer `json:"buyer,omitempty"`
// The date and time of the creation of the job, in ISO 8601 format.
CreateTime *time.Time `json:"createTime,omitempty"`
// The marketplace identifier.
MarketplaceId *string `json:"marketplaceId,omitempty"`
// A list of appointment windows preferred by the buyer. Included only if the buyer selected appointment windows when creating the order.
PreferredAppointmentTimes *[]AppointmentTime `json:"preferredAppointmentTimes,omitempty"`
// The scope of work for the order.
ScopeOfWork *ScopeOfWork `json:"scopeOfWork,omitempty"`
// Information about the seller of the service job.
Seller *Seller `json:"seller,omitempty"`
// Amazon identifier for the service job.
ServiceJobId *ServiceJobId `json:"serviceJobId,omitempty"`
// Information about the service job provider.
ServiceJobProvider *ServiceJobProvider `json:"serviceJobProvider,omitempty"`
// The status of the service job.
ServiceJobStatus *string `json:"serviceJobStatus,omitempty"`
// Information about the location of the service job.
ServiceLocation *ServiceLocation `json:"serviceLocation,omitempty"`
// The Amazon-defined identifier for an order placed by the buyer, in 3-7-7 format.
ServiceOrderId *OrderId `json:"serviceOrderId,omitempty"`
}
ServiceJob defines model for ServiceJob.
type ServiceJobProvider ¶
type ServiceJobProvider struct {
// The identifier of the service job provider.
ServiceJobProviderId *string `json:"serviceJobProviderId,omitempty"`
}
ServiceJobProvider defines model for ServiceJobProvider.
type ServiceLocation ¶
type ServiceLocation struct {
// The shipping address for the service job.
Address *Address `json:"address,omitempty"`
// The location of the service job.
ServiceLocationType *string `json:"serviceLocationType,omitempty"`
}
ServiceLocation defines model for ServiceLocation.
type SetAppointmentResponse ¶
type SetAppointmentResponse struct {
// The appointment identifier.
AppointmentId *AppointmentId `json:"appointmentId,omitempty"`
// A list of error responses returned when a request is unsuccessful.
Errors *ErrorList `json:"errors,omitempty"`
// A list of warnings returned in the sucessful execution response of an API request.
Warnings *WarningList `json:"warnings,omitempty"`
}
SetAppointmentResponse defines model for SetAppointmentResponse.
type Technician ¶
type Technician struct {
// The name of the technician.
Name *string `json:"name,omitempty"`
// The technician identifier.
TechnicianId *string `json:"technicianId,omitempty"`
}
Technician defines model for Technician.
type Warning ¶
type Warning struct {
// An warning code that identifies the type of warning that occurred.
Code string `json:"code"`
// Additional details that can help the caller understand or address the warning.
Details *string `json:"details,omitempty"`
// A message that describes the warning condition in a human-readable form.
Message string `json:"message"`
}
Warning defines model for Warning.